@@ -4,6 +4,7 @@
 A script to submit a Work Requirement.
 """
 
+from copy import deepcopy
 from datetime import timedelta
 from math import ceil
 from os import chdir
@@ -72,9 +73,12 @@ from yd_commands.validate_properties import validate_properties
 from yd_commands.variables import (
     L_TASK_COUNT,
     L_TASK_GROUP_COUNT,
+    L_TASK_GROUP_NAME,
     L_TASK_GROUP_NUMBER,
+    L_TASK_NAME,
     L_TASK_NUMBER,
     L_WR_NAME,
+    add_substitution_overwrite,
     add_substitutions,
     load_json_file_with_variable_substitutions,
     load_jsonnet_file_with_variable_substitutions,
@@ -209,7 +213,7 @@ def submit_work_requirement(
     # Overwrite the WR name?
     global ID, CONFIG_WR
     ID = format_yd_name(
-        wr_data.get(L_WR_NAME, ID if CONFIG_WR.wr_name is None else CONFIG_WR.wr_name)
+        wr_data.get(NAME, ID if CONFIG_WR.wr_name is None else CONFIG_WR.wr_name)
     )
     # Lazy substitution of the Work Requirement name, now it's defined
     add_substitutions(subs={L_WR_NAME: ID})
@@ -304,6 +308,12 @@ def create_task_group(
     # Name the Task Group
     num_task_groups = len(wr_data[TASK_GROUPS])
     num_tasks = len(task_group_data[TASKS])
+    # The following handles possible CSV substitution at the config.toml level
+    try:
+        if task_group_data.get(NAME, None) is None:
+            task_group_data[NAME] = task_group_data[TASKS][0][TASK_GROUP_NAME]
+    except KeyError:
+        pass
     task_group_name = format_yd_name(
         get_task_group_name(
             task_group_data.get(NAME, CONFIG_WR.task_group_name),
@@ -451,7 +461,11 @@ def add_tasks_to_task_group(
     task_group_task_count = wr_data[TASK_GROUPS][tg_number].get(TASK_COUNT, None)
     if task_group_task_count is not None:
         if num_tasks == 1:
-            task_count = check_int(task_group_task_count)
+            # Expand the number of Tasks to match the specified Task count
+            for _ in range(1, int(task_group_task_count)):
+                wr_data[TASK_GROUPS][tg_number][TASKS].append(
+                    deepcopy(wr_data[TASK_GROUPS][tg_number][TASKS][0])
+                )
         else:
             print_log(
                 f"Warning: Task Group '{task_group.name}' contains {num_tasks} "
@@ -462,7 +476,7 @@ def add_tasks_to_task_group(
 
     # Determine Task batching
     tasks = wr_data[TASK_GROUPS][tg_number][TASKS]
-    num_tasks = len(tasks) if task_count is None else task_count
+    num_tasks = len(tasks)
     num_task_batches: int = ceil(num_tasks / TASK_BATCH_SIZE)
     tasks_list: List[Task] = []
     if num_task_batches > 1 and not ARGS_PARSER.dry_run:
@@ -471,6 +485,14 @@ def add_tasks_to_task_group(
             f"{num_task_batches} batches"
         )
 
+    # Add lazy substitutions for use in any Task property
+    add_substitution_overwrite(L_TASK_COUNT, str(num_tasks))
+    add_substitution_overwrite(L_TASK_GROUP_NAME, task_group.name)
+    add_substitution_overwrite(
+        L_TASK_GROUP_NUMBER, formatted_number_str(tg_number, num_task_groups)
+    )
+    add_substitution_overwrite(L_TASK_GROUP_COUNT, str(num_task_groups))
+
     # Iterate through batches
     for batch_number in range(num_task_batches):
         # Iterate through tasks in the batch
@@ -479,16 +501,23 @@ def add_tasks_to_task_group(
             min(TASK_BATCH_SIZE * (batch_number + 1), num_tasks),
         ):
             task_group_data = wr_data[TASK_GROUPS][tg_number]
-            task = tasks[task_number] if task_count is None else tasks[0]
+            task = tasks[task_number]
             task_name = format_yd_name(
                 get_task_name(
-                    task.get(NAME, CONFIG_WR.task_name),
+                    task.get(NAME, task.get(TASK_NAME, CONFIG_WR.task_name)),
                     task_number,
                     num_tasks,
                     tg_number,
                     num_task_groups,
                 )
             )
+
+            add_substitution_overwrite(L_TASK_NAME, str(task_name))
+            add_substitution_overwrite(
+                L_TASK_NUMBER, formatted_number_str(task_number, num_tasks)
+            )
+            process_variable_substitutions(task)
+
             executable = check_str(
                 task.get(
                     EXECUTABLE,
@@ -1038,7 +1067,7 @@ def submit_json_raw(wr_file: str):
     wr_data["name"] = format_yd_name(wr_data["name"])
     wr_name = wr_data["name"]
     add_substitutions(subs={L_WR_NAME: wr_name})
-    process_variable2_substitutions(wr_data)
+    process_variable_substitutions(wr_data)
 
     if ARGS_PARSER.dry_run:
         # This will show the results of any variable substitutions
